/**
 * @license Copyright (c) 2003-2022, RAONWIZ DevTeam. All rights reserved.
 */
/// <reference types="react" />
import * as PropTypes from 'prop-types';
import { ComponentProps } from './types';
/**
 * `RAONWIZ` component is a convenient wrapper around low-level hooks.
 * It's useful for simpler use cases. For advanced usage see `useDEXT5Editor` hook.
 */
declare function DEXT5Editor<EventHandlerProp>({ debug, id, config, componentUrl, createMode, initData, readOnly, 
/**
 * `handlers` object must contain event handlers props only!
 */
...handlers }: ComponentProps<EventHandlerProp>): JSX.Element;
declare namespace DEXT5Editor {
    var propTypes: {
        onBeforeLoad: PropTypes.Requireable<(...args: any[]) => any>;
        onNamespaceLoaded: PropTypes.Requireable<(...args: any[]) => any>;
        onLoaded: PropTypes.Requireable<(...args: any[]) => any>;
        onCreationComplete: PropTypes.Requireable<(...args: any[]) => any>;
        onDestroy: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Config object passed to component's constructor.
         *
         * A new instance of component will be created everytime a new instance of `config` is provided.
         * If this is not expected behavior then ensure referential equality of `config` between renders.
         */
        config: PropTypes.Requireable<object>;
        /**
         * Toggles debugging. Logs info related to component lifecycle events.
         */
        debug: PropTypes.Requireable<boolean>;
        /**
         * Url with component's source code.
         */
        componentUrl: PropTypes.Requireable<string>;
        /**
         * createMode.
         */
        createMode: PropTypes.Requireable<string>;
        /**
         * A unique identifier of component instance.
         */
        id: PropTypes.Requireable<string>;
        /**
         * Initial data will be set only once during editor instance's lifecycle.
         */
        initData: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /**
         * This prop has two-fold effect:
         */
        readOnly: PropTypes.Requireable<boolean>;
    };
}
export default DEXT5Editor;
